.. _user_guide_installation:

============
Installation
============

.. TODO: link to PyPI mater page.
MATER can be installed via pip from `PyPI <https://pypi.org/>`_.

.. code-block:: bash

   pip install mater